@@ -154,7 +154,7 @@ class C32:
 
             return RVInstruction(
                 rv_format="CI",
-                rv_src_registers=[data["x0"]],
+                rv_src_registers=["x0"],
                 rv_dest_registers=[data["register"]],
                 rv_immediates=[fp.immToInt(imm)],
                 rv_name="c.li",
@@ -240,8 +240,8 @@ class C32:
                 shamt = bitarray([data["offset3"][0]]) + data["offset5"]
                 return RVInstruction(
                     rv_format="CB",
-                    rv_src_registers=[data["register"]],
-                    rv_dest_registers=[data["register"]],
+                    rv_src_registers=[data["rs1_pop"]],
+                    rv_dest_registers=[data["rs1_pop"]],
                     rv_immediates=[fp.immToInt(shamt)],
                     rv_name="c.srai",
                     rv_size=16,
