@@ -7,18 +7,19 @@ class Program:
     """A Program is a collection of instructions which are mapped to pc values"""
 
     def __init__(self, isa="32I"):
-        self.rv = RV32(isa)
+        self.rv = RV32(isa=isa)
         self.instructions = {}  # maps pc value -> RVInstruction
         self.frequencies = {}  # maps pc value -> frequency of instruction
+        self.instructionNameSet = None
 
-    def addInstruction(self, pc, hex, freq):
+    def addInstruction(self, pc, hexd, freq):
         """Adds an instruction to a Program given a PC value
         and the instruction hex value
 
         pc - (int) program counter (pc)
-        hex - (str) instruction encoded in hexadecimal
+        hexd - (str) instruction encoded in hexadecimal
         freq - (int) amount of times instruction shows up"""
-        self.instructions[pc] = self.rv.decodeHex(hex)
+        self.instructions[pc] = self.rv.decodeHex(hexd)
 
         # TODO decouple storing frequencies from program?
         self.frequencies[pc] = freq
@@ -32,5 +33,5 @@ class Program:
 
     def printAll(self, file=sys.stdout):
         """Prints out all instructions to file (default is stdout)"""
-        for pc in self.program:
+        for pc in self.instructions:
             print("{}: {}".format(hex(pc), self.instructions[pc]), file=file)
