@@ -3,7 +3,7 @@ from . import M32
 from . import RVFormatParser
 from . import V32
 from . import C32
-import sys
+from bitarray import bitarray
 
 
 class RV32:
@@ -15,30 +15,33 @@ class RV32:
 
         # a mapping from frozenbitarray of opcode --> function that returns an RVInstruction
         self.instructionTable = {}
+        self.instructionNameSet = set()
 
         if "32I" in isa:
             self.instructionTable.update(I32.instructionTable)
+            self.instructionNameSet.update(I32.instructionNameSet)
         if "M" in isa:
             self.instructionTable.update(M32.instructionTable)
+            self.instructionNameSet.update(M32.instructionNameSet)
         if "V" in isa:
             self.instructionTable.update(V32.instructionTable)
+            # TODO add inst name set
         if "C" in isa:
             self.instructionTable.update(C32.instructionTable)
+            self.instructionNameSet.update(C32.instructionNameSet)
 
-        # the program is a mapping from a pc int --> RVInstruction
-        self.program = {}
+    def decodeHex(self, hex):
+        bstr = bitarray(bin(int(hex, 16))[2:]).to01()
+        size = 32
+
+        # compressed instructions NEVER end in 11
+        if bstr[-2:] != "11":
+            size = 16
+
+        bstr = bstr.zfill(size)
+        ba = bitarray(bstr)
+
+        return self.decode(ba)
 
     def decode(self, ba):
         return self.instructionTable[RVFormatParser.getOpcode(ba)](ba)
-
-    def addInstruction(self, pc, ba):
-        """ Adds Instruction from pc into program map
-            pc - an integer (program counter)
-            ba - the bitarray for the instruction
-        """
-        self.program[pc] = self.decode(ba)
-
-    def printAll(self, file=sys.stdout):
-        """ Prints out all instructions """
-        for pc in self.program:
-            print("{}: {}".format(hex(pc), self.program[pc]), file=file)
